"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.OpenApi = void 0;
const oas_builder_1 = __importDefault(require("@avanzu/oas-builder"));
const decorators_1 = require("../../decorators");
const node_path_1 = require("node:path");
class OpenApi {
    constructor(info) {
        this.info = info;
    }
    generate() {
        const paths = new Map();
        for (const controller of (0, decorators_1.getControllers)()) {
            const mount = (0, decorators_1.getMountPoints)(controller);
            for (const endpoint of mount.endpoints) {
                const pathName = (0, node_path_1.join)(mount.prefix, endpoint.route);
                const operationId = `${endpoint.target.name}.${endpoint.method.toString()}`;
                const op = oas_builder_1.default.op().id(operationId);
                paths.set(pathName, oas_builder_1.default.path().method(endpoint.verb, op));
            }
        }
        const pathDict = Object.fromEntries(paths);
        const doc = oas_builder_1.default.document().paths(pathDict)
            .info(oas_builder_1.default.info()
            .title(this.info.title)
            .summary(this.info.description)
            .version(this.info.version));
        return doc.valueOf();
    }
}
exports.OpenApi = OpenApi;
//# sourceMappingURL=openapi.js.map